### container

gguf-container frontend (gguf.us)

#### install it via:
```
pip install gguf-container
```

#### run the container frontend by:
```
python -m gguf_container
```

find the full source code in this pack; you can opt to run the server.py and host the frontend locally